pub struct LuaRuntimeType(pub RuntimeType);Tuple Fields
0: RuntimeTypeTrait Implementations
Sourceimpl Clone for LuaRuntimeType
impl Clone for LuaRuntimeType
Sourcefn clone(&self) -> LuaRuntimeType
fn clone(&self) -> LuaRuntimeType
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LuaRuntimeType
impl Debug for LuaRuntimeType
Sourceimpl Deref for LuaRuntimeType
impl Deref for LuaRuntimeType
Sourceimpl From<LuaRuntimeType> for RuntimeType
impl From<LuaRuntimeType> for RuntimeType
Sourcefn from(value: LuaRuntimeType) -> Self
fn from(value: LuaRuntimeType) -> Self
Converts to this type from the input type.
Sourceimpl From<RuntimeType> for LuaRuntimeType
impl From<RuntimeType> for LuaRuntimeType
Sourcefn from(value: RuntimeType) -> Self
fn from(value: RuntimeType) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for LuaRuntimeType
impl PartialEq for LuaRuntimeType
Sourcefn eq(&self, other: &LuaRuntimeType) -> bool
fn eq(&self, other: &LuaRuntimeType) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl UserData for LuaRuntimeType
impl UserData for LuaRuntimeType
Sourcefn add_methods<M: UserDataMethods<Self>>(methods: &mut M)
fn add_methods<M: UserDataMethods<Self>>(methods: &mut M)
Adds custom methods and operators specific to this userdata.
Sourcefn add_fields<F>(fields: &mut F)where
F: UserDataFields<Self>,
fn add_fields<F>(fields: &mut F)where
F: UserDataFields<Self>,
Adds custom fields specific to this userdata.
Sourcefn register(registry: &mut UserDataRegistry<Self>)
fn register(registry: &mut UserDataRegistry<Self>)
Registers this type for use in Lua. Read more
impl Eq for LuaRuntimeType
impl StructuralPartialEq for LuaRuntimeType